@@ -19,12 +19,12 @@ def signup():
     
     p = getpass.getpass()
     
-    response = User().signup(username, name, email, p)
+    response = UserAPIClient().signup(username, name, email, p)
     print(response['message'])
     
     print("Enter verification code")
     code = input()
-    response = User().confirm_signup(username, name, code)
+    response = UserAPIClient().confirm_signup(username, name, code)
     print(response['message'])
     
     UserAPIClient().signin(username, p)
